@@ -19,15 +19,16 @@
 */
 
 #include "module.h"
-#include "module-formats.h"
-#include "signals.h"
-#include "commands.h"
-#include "levels.h"
-#include "misc.h"
+#include <time.h>
+#include <irssi/src/fe-common/core/module-formats.h>
+#include <irssi/src/core/signals.h>
+#include <irssi/src/core/commands.h>
+#include <irssi/src/core/levels.h>
+#include <irssi/src/core/misc.h>
 
-#include "servers.h"
-#include "ignore.h"
-#include "printtext.h"
+#include <irssi/src/core/servers.h>
+#include <irssi/src/core/ignore.h>
+#include <irssi/src/fe-common/core/printtext.h>
 
 static char *ignore_get_key(IGNORE_REC *rec)
 {
@@ -48,6 +49,8 @@ static void ignore_print(int index, IGNORE_REC *rec)
 {
 	GString *options;
 	char *key, *levels;
+	struct tm ts;
+	char buf[20];
 
 	key = ignore_get_key(rec);
 	levels = bits2level(rec->level);
@@ -67,6 +70,11 @@ static void ignore_print(int index, IGNORE_REC *rec)
 		g_string_append_printf(options, "-network %s ", rec->servertag);
 	if (rec->pattern != NULL)
 		g_string_append_printf(options, "-pattern %s ", rec->pattern);
+	if (rec->unignore_time != 0) {
+		ts = *localtime(&rec->unignore_time);
+		strftime(buf, sizeof(buf), "%Y-%m-%d %H:%M:%S", &ts);
+		g_string_append_printf(options, "ignore ends: %s ", buf);
+	}
 
 	if (options->len > 1) g_string_truncate(options, options->len-1);
 
@@ -107,9 +115,9 @@ static void cmd_ignore_show(void)
 }
 
 /* SYNTAX: IGNORE [-regexp | -full] [-pattern <pattern>] [-except] [-replies]
-                  [-network <network>] [-channels <channel>] [-time <secs>] <mask> [<levels>]
+                  [-network <network>] [-channels <channel>] [-time <time>] <mask> [<levels>]
            IGNORE [-regexp | -full] [-pattern <pattern>] [-except] [-replies]
-	          [-network <network>] [-time <secs>] <channels> [<levels>] */
+                  [-network <network>] [-time <time>] <channels> [<levels>] */
 /* NOTE: -network replaces the old -ircnet flag. */
 static void cmd_ignore(const char *data)
 {
@@ -161,6 +169,8 @@ static void cmd_ignore(const char *data)
 		flags |= IGNORE_FIND_NOACT;
 	if (level & MSGLEVEL_HIDDEN)
 		flags |= IGNORE_FIND_HIDDEN;
+	if (level & MSGLEVEL_NOHILIGHT)
+		flags |= IGNORE_FIND_NOHILIGHT;
 
 	rec = ignore_find_full(servertag, mask, patternarg, channels, flags);
 	new_ignore = rec == NULL;
@@ -190,6 +200,12 @@ static void cmd_ignore(const char *data)
 		rec->level |= MSGLEVEL_ALL;
 	}
 
+	if (rec->level == MSGLEVEL_NOHILIGHT) {
+		/* If only NOHILIGHT was specified add all levels; it makes no
+		 * sense on its own. */
+		rec->level |= MSGLEVEL_ALL;
+	}
+
 	if (new_ignore && rec->level == 0) {
 		/* tried to unignore levels from nonexisting ignore */
 		printformat(NULL, NULL, MSGLEVEL_CLIENTNOTICE,
