@@ -19,16 +19,16 @@
 */
 
 #include "module.h"
-#include "module-formats.h"
-#include "signals.h"
-#include "commands.h"
-#include "levels.h"
-#include "misc.h"
-#include "settings.h"
-#include "printtext.h"
+#include <irssi/src/fe-text/module-formats.h>
+#include <irssi/src/core/signals.h>
+#include <irssi/src/core/commands.h>
+#include <irssi/src/core/levels.h>
+#include <irssi/src/core/misc.h>
+#include <irssi/src/core/settings.h>
+#include <irssi/src/fe-common/core/printtext.h>
 
-#include "term.h"
-#include "gui-windows.h"
+#include <irssi/src/fe-text/term.h>
+#include <irssi/src/fe-text/gui-windows.h>
 
 #define NEW_WINDOW_SIZE (WINDOW_MIN_SIZE + 1)
 
@@ -1298,9 +1298,7 @@ static void window_balance_vertical(void)
 				rec->last_line++;
 			}
 
-			rec->height = rec->last_line-rec->first_line+1;
-
-			mainwindow_resize(rec, 0, rec->height-old_size);
+			mainwindow_resize(rec, 0, rec->last_line - rec->first_line + 1 - old_size);
 		}
 		if (line != NULL && bigger_units > 0) {
 			bigger_units--;
@@ -1644,9 +1642,9 @@ static int window_refnum_left(int refnum, int wrap)
 			break;
 
 		window = window_find_refnum(refnum);
-	} while (!WINDOW_STICKY_MATCH(window, find_sticky));
+	} while (!WINDOW_STICKY_MATCH(window, find_sticky) || is_window_visible(window));
 
-        return refnum;
+	return refnum;
 }
 
 static int window_refnum_right(int refnum, int wrap)
@@ -1666,9 +1664,9 @@ static int window_refnum_right(int refnum, int wrap)
 			break;
 
 		window = window_find_refnum(refnum);
-	} while (!WINDOW_STICKY_MATCH(window, find_sticky));
+	} while (!WINDOW_STICKY_MATCH(window, find_sticky) || is_window_visible(window));
 
-        return refnum;
+	return refnum;
 }
 
 /* SYNTAX: WINDOW LEFT [-directional] */
